update

package
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 2, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckForUpdates

func CheckForUpdates(ctx context.Context) (string, bool, error)

CheckForUpdates checks if a newer version is available on GitHub Releases Returns (latestVersion, isAvailable, error) This function is designed to be safe for non-interactive use (e.g., version command) It will timeout and return errors gracefully instead of hanging or panicking

func Upgrade

func Upgrade(ctx context.Context, verbose bool) error

Upgrade downloads and installs the latest version

Types

This section is empty.

Jump to